==> nextcloud-12.0.2.tgz: nextcloud/apps/updatenotification/l10n/lv.js <==
OC.L10N.register(
    "updatenotification",
    {
    "Update notifications" : "Atjauninājumu paziņojumi",
    "Could not start updater, please try the manual update" : "Nevar sākt atjauninājumu, lūdzu, mēģiniet manuālo atjauninājumu",
    "{version} is available. Get more information on how to update." : "{version} ir pieejama. Iegūstiet vairāk informācijas par to, kā atjaunināt.",
    "Channel updated" : "Kanāls atjaunots",
    "Update to %1$s is available." : "Atjauninājums uz %1$s ir pieejams.",
    "Update for %1$s to version %2$s is available." : "Atjauninājums %1$s uz versiju %2$s ir pieejams.",
    "Update for {app} to version %s is available." : "Atjauninājums {app} uz versiju %s ir pieejams.",
    "A new version is available: %s" : "Ir pieejama jauna versija: %s",
    "Open updater" : "Atveriet atjauninātāju",
    "Download now" : "Lejupielādēt tagad",
    "Your version is up to date." : "Jums ir jaunākā versija.",
    "Checked on %s" : "Pārbaudīts %s",
    "Update channel:" : "Atjaunināt kanālu:",
    "You can always update to a newer version / experimental channel. But you can never downgrade to a more stable channel." : "Jūs vienmēr varat atjaunināt to uz jaunāku versiju / eksperimentālo versiju. Bet nekad nevar atgriezties uz stabilāku versiju.",
    "Notify members of the following groups about available updates:" : "Paziņot šo grupu locekļiem par pieejamajiem atjauninājumiem:",
    "Only notification for app updates are available." : "Tikai paziņojumi par programmu atjauninājumiem ir pieejami.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Izvēlētais atjauninājumu kanāls rādīs īpašus paziņojumus ja serveris novecojis.",
    "The selected update channel does not support updates of the server." : "Izvēlēto atjauninājumu kanāls neatbalsta servera atjauninājumus."
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");

==> nextcloud-13.0.1.tgz: nextcloud/apps/updatenotification/l10n/lv.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} ir pieejama. Iegūstiet vairāk informācijas par to, kā atjaunināt.",
    "Open updater" : "Atveriet atjauninātāju",
    "Your version is up to date." : "Jums ir jaunākā versija.",
    "Update channel:" : "Atjaunināt kanālu:",
    "You can always update to a newer version / experimental channel. But you can never downgrade to a more stable channel." : "Jūs vienmēr varat atjaunināt to uz jaunāku versiju / eksperimentālo versiju. Bet nekad nevar atgriezties uz stabilāku versiju.",
    "Notify members of the following groups about available updates:" : "Paziņot šo grupu locekļiem par pieejamajiem atjauninājumiem:",
    "Only notification for app updates are available." : "Tikai paziņojumi par programmu atjauninājumiem ir pieejami.",
    "The selected update channel does not support updates of the server." : "Izvēlēto atjauninājumu kanāls neatbalsta servera atjauninājumus.",
    "Could not start updater, please try the manual update" : "Nevar sākt atjauninājumu, lūdzu, mēģiniet manuālo atjauninājumu",
    "Update notifications" : "Atjauninājumu paziņojumi",
    "Channel updated" : "Kanāls atjaunots",
    "Update to %1$s is available." : "Atjauninājums uz %1$s ir pieejams.",
    "Update for %1$s to version %2$s is available." : "Atjauninājums %1$s uz versiju %2$s ir pieejams.",
    "Update for {app} to version %s is available." : "Atjauninājums {app} uz versiju %s ir pieejams.",
    "A new version is available: %s" : "Ir pieejama jauna versija: %s",
    "Download now" : "Lejupielādēt tagad",
    "Checked on %s" : "Pārbaudīts %s",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Izvēlētais atjauninājumu kanāls rādīs īpašus paziņojumus ja serveris novecojis."
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
